package it.cavallium;

import java.io.File;
import java.io.RandomAccessFile;
import java.nio.channels.FileLock;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SystemUtils {

	private static final Logger log = LoggerFactory.getLogger(SystemUtils.class);

	public static boolean lockInstance(final String lockFile) {
		try {
			final File file = new File(lockFile);
			final RandomAccessFile randomAccessFile = new RandomAccessFile(file, "rw");
			final FileLock fileLock = randomAccessFile.getChannel().tryLock();
			if (fileLock != null) {
				Runtime.getRuntime().addShutdownHook(new Thread(() -> {
					try {
						fileLock.release();
						randomAccessFile.close();
						if (!file.delete()) {
							log.warn("Unable to delete lock file: " + lockFile);
						}
					} catch (Exception e) {
						System.err.println();
						log.error("Unable to remove lock file: " + lockFile, e);
					}
				}));
				return true;
			}
		} catch (Exception e) {
			log.error("Unable to create and/or lock file: " + lockFile, e);
		}
		return false;
	}

}
